You can subscribe to this list here.
| 2001 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
(135) |
Nov
(123) |
Dec
(83) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2002 |
Jan
(244) |
Feb
(72) |
Mar
(221) |
Apr
(91) |
May
(104) |
Jun
(93) |
Jul
(78) |
Aug
(1) |
Sep
(1) |
Oct
(29) |
Nov
(98) |
Dec
(20) |
| 2003 |
Jan
|
Feb
(21) |
Mar
|
Apr
(1) |
May
|
Jun
|
Jul
|
Aug
(18) |
Sep
(18) |
Oct
(23) |
Nov
(12) |
Dec
(6) |
| 2004 |
Jan
(2) |
Feb
(32) |
Mar
|
Apr
(12) |
May
(11) |
Jun
(11) |
Jul
|
Aug
(9) |
Sep
|
Oct
(15) |
Nov
|
Dec
|
| 2005 |
Jan
|
Feb
(2) |
Mar
(11) |
Apr
(6) |
May
(1) |
Jun
(9) |
Jul
(7) |
Aug
|
Sep
|
Oct
|
Nov
|
Dec
(1) |
| 2006 |
Jan
|
Feb
(1) |
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
|
Nov
|
Dec
|
| 2007 |
Jan
|
Feb
(2) |
Mar
|
Apr
(25) |
May
(2) |
Jun
|
Jul
(5) |
Aug
|
Sep
|
Oct
|
Nov
|
Dec
|
| 2008 |
Jan
|
Feb
|
Mar
(1) |
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
|
Nov
|
Dec
|
| 2009 |
Jan
|
Feb
(1) |
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
|
Nov
|
Dec
|
| 2010 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(13) |
Oct
|
Nov
(2) |
Dec
(2) |
| 2011 |
Jan
|
Feb
|
Mar
(10) |
Apr
(10) |
May
(1) |
Jun
(6) |
Jul
|
Aug
(2) |
Sep
(5) |
Oct
|
Nov
|
Dec
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/kernel In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/kernel Modified Files: printk.c Log Message: Synced to 2.5.7 Index: printk.c =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/kernel/printk.c,v retrieving revision 1.27 retrieving revision 1.28 diff -u -d -r1.27 -r1.28 --- printk.c 14 Mar 2002 17:53:54 -0000 1.27 +++ printk.c 22 Mar 2002 20:13:58 -0000 1.28 @@ -30,7 +30,14 @@ #include <asm/uaccess.h> -#define LOG_BUF_LEN (16384) /* This must be a power of two */ +#if defined(CONFIG_MULTIQUAD) || defined(CONFIG_IA64) +#define LOG_BUF_LEN (65536) +#elif defined(CONFIG_SMP) +#define LOG_BUF_LEN (32768) +#else +#define LOG_BUF_LEN (16384) /* This must be a power of two */ +#endif + #define LOG_BUF_MASK (LOG_BUF_LEN-1) /* printk's without a loglevel use this.. */ |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/include/linux
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/include/linux
Modified Files:
hiddev.h
Log Message:
Synced to 2.5.7
Index: hiddev.h
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/include/linux/hiddev.h,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- hiddev.h 25 Sep 2001 09:37:57 -0000 1.6
+++ hiddev.h 22 Mar 2002 20:13:58 -0000 1.7
@@ -119,6 +119,7 @@
__s32 value;
};
+#define HID_FIELD_INDEX_NONE 0xffffffff
/*
* Protocol version.
@@ -143,6 +144,15 @@
#define HIDIOCGUSAGE _IOWR('H', 0x0B, struct hiddev_usage_ref)
#define HIDIOCSUSAGE _IOW('H', 0x0C, struct hiddev_usage_ref)
#define HIDIOCGUCODE _IOWR('H', 0x0D, struct hiddev_usage_ref)
+#define HIDIOCGFLAG _IOR('H', 0x0E, int)
+#define HIDIOCSFLAG _IOW('H', 0x0F, int)
+
+/*
+ * Flags to be used in HIDIOCSFLAG
+ */
+#define HIDDEV_FLAG_UREF 0x1
+#define HIDDEV_FLAG_REPORT 0x2
+#define HIDDEV_FLAGS 0x3
/* To traverse the input report descriptor info for a HID device, perform the
* following:
@@ -179,7 +189,7 @@
#ifdef CONFIG_USB_HIDDEV
int hiddev_connect(struct hid_device *);
void hiddev_disconnect(struct hid_device *);
-void hiddev_hid_event(struct hid_device *, unsigned int usage, int value);
+void hiddev_hid_event(struct hid_device *, struct hiddev_usage_ref *ref);
int __init hiddev_init(void);
void __exit hiddev_exit(void);
#else
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/ia64/kernel
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/ia64/kernel
Modified Files:
setup.c traps.c
Log Message:
Synced to 2.5.7
Index: setup.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ia64/kernel/setup.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- setup.c 26 Dec 2001 17:28:11 -0000 1.3
+++ setup.c 22 Mar 2002 20:13:57 -0000 1.4
@@ -3,7 +3,7 @@
*
* Copyright (C) 1998-2001 Hewlett-Packard Co
* David Mosberger-Tang <da...@hp...>
- * Copyright (C) 1998, 1999, 2001 Stephane Eranian <er...@hp...>
+ * Stephane Eranian <er...@hp...>
* Copyright (C) 2000, Rohit Seth <roh...@in...>
* Copyright (C) 1999 VA Linux Systems
* Copyright (C) 1999 Walt Drummond <dru...@va...>
@@ -27,6 +27,7 @@
#include <linux/seq_file.h>
#include <linux/string.h>
#include <linux/threads.h>
+#include <linux/tty.h>
#include <asm/acpi-ext.h>
#include <asm/ia32.h>
@@ -52,12 +53,10 @@
extern char _end;
-#ifdef CONFIG_NUMA
- struct cpuinfo_ia64 *boot_cpu_data;
-#else
- struct cpuinfo_ia64 _cpu_data[NR_CPUS] __attribute__ ((section ("__special_page_section")));
-#endif
+unsigned long __per_cpu_offset[NR_CPUS];
+struct cpuinfo_ia64 cpu_info __per_cpu_data;
+unsigned long ia64_phys_stacked_size_p8;
unsigned long ia64_cycles_per_usec;
struct ia64_boot_param *ia64_boot_param;
struct screen_info screen_info;
@@ -146,6 +145,10 @@
}
+/*
+ * Find a place to put the bootmap and return its starting address in bootmap_start.
+ * This address must be page-aligned.
+ */
static int
find_bootmap_location (unsigned long start, unsigned long end, void *arg)
{
@@ -164,7 +167,7 @@
for (i = 0; i < num_rsvd_regions; i++) {
range_start = MAX(start, free_start);
- range_end = MIN(end, rsvd_region[i].start);
+ range_end = MIN(end, rsvd_region[i].start & PAGE_MASK);
if (range_end <= range_start) continue; /* skip over empty range */
@@ -176,7 +179,7 @@
/* nothing more available in this segment */
if (range_end == end) return 0;
- free_start = rsvd_region[i].end;
+ free_start = PAGE_ALIGN(rsvd_region[i].end);
}
return 0;
}
@@ -305,6 +308,10 @@
/* process SAL system table: */
ia64_sal_init(efi.sal_systab);
+#ifdef CONFIG_IA64_GENERIC
+ machvec_init(acpi_get_sysname());
+#endif
+
/*
* Set `iobase' to the appropriate address in region 6
* (uncached access range)
@@ -331,10 +338,6 @@
cpu_init(); /* initialize the bootstrap CPU */
-#ifdef CONFIG_IA64_GENERIC
- machvec_init(acpi_get_sysname());
-#endif
-
if (efi.acpi20) {
/* Parse the ACPI 2.0 tables */
acpi20_parse(efi.acpi20);
@@ -362,17 +365,14 @@
{
#ifdef CONFIG_SMP
# define lpj c->loops_per_jiffy
+# define cpunum c->cpu
#else
# define lpj loops_per_jiffy
+# define cpunum 0
#endif
char family[32], features[128], *cp;
struct cpuinfo_ia64 *c = v;
- unsigned long mask, cpu = c - cpu_data(0);
-
-#ifdef CONFIG_SMP
- if (!(cpu_online_map & (1 << cpu)))
- return 0;
-#endif
+ unsigned long mask;
mask = c->features;
@@ -394,7 +394,7 @@
sprintf(cp, " 0x%lx", mask);
seq_printf(m,
- "processor : %lu\n"
+ "processor : %d\n"
"vendor : %s\n"
"arch : IA-64\n"
"family : %s\n"
@@ -407,7 +407,7 @@
"cpu MHz : %lu.%06lu\n"
"itc MHz : %lu.%06lu\n"
"BogoMIPS : %lu.%02lu\n\n",
- cpu, c->vendor, family, c->model, c->revision, c->archrev,
+ cpunum, c->vendor, family, c->model, c->revision, c->archrev,
features, c->ppn, c->number,
c->proc_freq / 1000000, c->proc_freq % 1000000,
c->itc_freq / 1000000, c->itc_freq % 1000000,
@@ -418,6 +418,10 @@
static void *
c_start (struct seq_file *m, loff_t *pos)
{
+#ifdef CONFIG_SMP
+ while (*pos < NR_CPUS && !(cpu_online_map & (1 << *pos)))
+ ++*pos;
+#endif
return *pos < NR_CPUS ? cpu_data(*pos) : NULL;
}
@@ -474,6 +478,9 @@
cpuid.bits[i] = ia64_get_cpuid(i);
memcpy(c->vendor, cpuid.field.vendor, 16);
+#ifdef CONFIG_SMP
+ c->cpu = smp_processor_id();
+#endif
c->ppn = cpuid.field.ppn;
c->number = cpuid.field.number;
c->revision = cpuid.field.revision;
@@ -493,6 +500,12 @@
c->unimpl_pa_mask = ~((1L<<63) | ((1L << phys_addr_size) - 1));
}
+void
+setup_per_cpu_areas (void)
+{
+ /* start_kernel() requires this... */
+}
+
/*
* cpu_init() initializes state that is per-CPU. This function acts
* as a 'CPU state barrier', nothing should get across.
@@ -500,46 +513,21 @@
void
cpu_init (void)
{
+ extern char __per_cpu_start[], __phys_per_cpu_start[], __per_cpu_end[];
extern void __init ia64_mmu_init (void *);
unsigned long num_phys_stacked;
pal_vm_info_2_u_t vmi;
unsigned int max_ctx;
- struct cpuinfo_ia64 *my_cpu_data;
-#ifdef CONFIG_NUMA
- int cpu, order;
+ struct cpuinfo_ia64 *my_cpu_info;
+ void *my_cpu_data;
+ int cpu = smp_processor_id();
- /*
- * If NUMA is configured, the cpu_data array is not preallocated. The boot cpu
- * allocates entries for every possible cpu. As the remaining cpus come online,
- * they reallocate a new cpu_data structure on their local node. This extra work
- * is required because some boot code references all cpu_data structures
- * before the cpus are actually started.
- */
- if (!boot_cpu_data) {
- my_cpu_data = alloc_bootmem_pages_node(NODE_DATA(numa_node_id()),
- sizeof(struct cpuinfo_ia64));
- boot_cpu_data = my_cpu_data;
- my_cpu_data->cpu_data[0] = my_cpu_data;
- for (cpu = 1; cpu < NR_CPUS; ++cpu)
- my_cpu_data->cpu_data[cpu]
- = alloc_bootmem_pages_node(NODE_DATA(numa_node_id()),
- sizeof(struct cpuinfo_ia64));
- for (cpu = 1; cpu < NR_CPUS; ++cpu)
- memcpy(my_cpu_data->cpu_data[cpu]->cpu_data_ptrs,
- my_cpu_data->cpu_data, sizeof(my_cpu_data->cpu_data));
- } else {
- order = get_order(sizeof(struct cpuinfo_ia64));
- my_cpu_data = page_address(alloc_pages_node(numa_node_id(), GFP_KERNEL, order));
- memcpy(my_cpu_data, boot_cpu_data->cpu_data[smp_processor_id()],
- sizeof(struct cpuinfo_ia64));
- __free_pages(virt_to_page(boot_cpu_data->cpu_data[smp_processor_id()]),
- order);
- for (cpu = 0; cpu < NR_CPUS; ++cpu)
- boot_cpu_data->cpu_data[cpu]->cpu_data[smp_processor_id()] = my_cpu_data;
- }
-#else
- my_cpu_data = cpu_data(smp_processor_id());
-#endif
+ my_cpu_data = alloc_bootmem_pages(__per_cpu_end - __per_cpu_start);
+ memcpy(my_cpu_data, __phys_per_cpu_start, __per_cpu_end - __per_cpu_start);
+
+ __per_cpu_offset[cpu] = (char *) my_cpu_data - __per_cpu_start;
+
+ my_cpu_info = my_cpu_data + ((char *) &cpu_info - __per_cpu_start);
/*
* We can't pass "local_cpu_data" to identify_cpu() because we haven't called
@@ -547,7 +535,7 @@
* depends on the data returned by identify_cpu(). We break the dependency by
* accessing cpu_data() the old way, through identity mapped space.
*/
- identify_cpu(my_cpu_data);
+ identify_cpu(my_cpu_info);
/* Clear the stack memory reserved for pt_regs: */
memset(ia64_task_regs(current), 0, sizeof(struct pt_regs));
@@ -568,6 +556,8 @@
atomic_inc(&init_mm.mm_count);
current->active_mm = &init_mm;
+ if (current->mm)
+ BUG();
ia64_mmu_init(my_cpu_data);
@@ -606,5 +596,7 @@
printk ("cpu_init: PAL RSE info failed, assuming 96 physical stacked regs\n");
num_phys_stacked = 96;
}
- local_cpu_data->phys_stacked_size_p8 = num_phys_stacked*8 + 8;
+ /* size of physical stacked register partition plus 8 bytes: */
+ ia64_phys_stacked_size_p8 = num_phys_stacked*8 + 8;
+ platform_cpu_init();
}
Index: traps.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ia64/kernel/traps.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- traps.c 15 Mar 2002 18:28:11 -0000 1.1
+++ traps.c 22 Mar 2002 20:13:57 -0000 1.2
@@ -1,7 +1,7 @@
/*
* Architecture-specific trap handling.
*
- * Copyright (C) 1998-2001 Hewlett-Packard Co
+ * Copyright (C) 1998-2002 Hewlett-Packard Co
* David Mosberger-Tang <da...@hp...>
*
* 05/12/00 grao <gou...@in...> : added isr in siginfo for SIGFPE
@@ -32,6 +32,7 @@
#include <linux/kernel.h>
#include <linux/init.h>
#include <linux/sched.h>
+#include <linux/tty.h>
#include <asm/hardirq.h>
#include <asm/ia32.h>
@@ -68,6 +69,7 @@
#endif
} else {
int loglevel_save = console_loglevel;
+
oops_in_progress = 0;
/*
* OK, the message is on the console. Now we call printk() without
@@ -129,6 +131,8 @@
/* SIGILL, SIGFPE, SIGSEGV, and SIGBUS want these field initialized: */
siginfo.si_addr = (void *) (regs->cr_iip + ia64_psr(regs)->ri);
siginfo.si_imm = break_num;
+ siginfo.si_flags = 0; /* clear __ISR_VALID */
+ siginfo.si_isr = 0;
switch (break_num) {
case 0: /* unknown error */
@@ -348,6 +352,8 @@
siginfo.si_code = FPE_FLTDIV;
}
siginfo.si_isr = isr;
+ siginfo.si_flags = __ISR_VALID;
+ siginfo.si_imm = 0;
force_sig_info(SIGFPE, &siginfo, current);
}
} else {
@@ -368,6 +374,8 @@
siginfo.si_code = FPE_FLTRES;
}
siginfo.si_isr = isr;
+ siginfo.si_flags = __ISR_VALID;
+ siginfo.si_imm = 0;
force_sig_info(SIGFPE, &siginfo, current);
}
}
@@ -486,6 +494,8 @@
siginfo.si_errno = 0;
siginfo.si_addr = (void *) (regs->cr_iip + ia64_psr(regs)->ri);
siginfo.si_imm = vector;
+ siginfo.si_flags = __ISR_VALID;
+ siginfo.si_isr = isr;
force_sig_info(SIGILL, &siginfo, current);
return;
}
@@ -513,6 +523,10 @@
}
siginfo.si_signo = SIGTRAP;
siginfo.si_errno = 0;
+ siginfo.si_flags = 0;
+ siginfo.si_isr = 0;
+ siginfo.si_addr = 0;
+ siginfo.si_imm = 0;
force_sig_info(SIGTRAP, &siginfo, current);
return;
@@ -524,6 +538,9 @@
siginfo.si_errno = 0;
siginfo.si_code = FPE_FLTINV;
siginfo.si_addr = (void *) (regs->cr_iip + ia64_psr(regs)->ri);
+ siginfo.si_flags = __ISR_VALID;
+ siginfo.si_isr = isr;
+ siginfo.si_imm = 0;
force_sig_info(SIGFPE, &siginfo, current);
}
return;
@@ -533,6 +550,9 @@
siginfo.si_signo = SIGILL;
siginfo.si_code = ILL_BADIADDR;
siginfo.si_errno = 0;
+ siginfo.si_flags = 0;
+ siginfo.si_isr = 0;
+ siginfo.si_imm = 0;
siginfo.si_addr = (void *) (regs->cr_iip + ia64_psr(regs)->ri);
force_sig_info(SIGILL, &siginfo, current);
return;
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/drivers In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/drivers Modified Files: Makefile Log Message: Synced to 2.5.7 Index: Makefile =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/drivers/Makefile,v retrieving revision 1.30 retrieving revision 1.31 diff -u -d -r1.30 -r1.31 --- Makefile 18 Mar 2002 19:58:09 -0000 1.30 +++ Makefile 22 Mar 2002 20:13:58 -0000 1.31 @@ -8,12 +8,14 @@ mod-subdirs := dio mtd sbus macintosh usb input telephony sgi ide \ message/i2o message/fusion scsi md ieee1394 pnp isdn atm \ - fc4 net/hamradio i2c acpi bluetooth input/serio input/gameport + fc4 net/hamradio i2c acpi bluetooth input/serio \ + input/gameport parport hotplug -subdir-y := base parport char block net misc media cdrom hotplug video +subdir-y := base char block net misc media cdrom video subdir-m := $(subdir-y) - +subdir-$(CONFIG_PARPORT) += parport +subdir-$(CONFIG_HOTPLUG_PCI) += hotplug subdir-$(CONFIG_DIO) += dio subdir-$(CONFIG_PCI) += pci subdir-$(CONFIG_PCMCIA) += pcmcia |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/ppc In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/ppc Modified Files: Config.help config.in Log Message: Synced to 2.5.7 Index: Config.help =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ppc/Config.help,v retrieving revision 1.2 retrieving revision 1.3 diff -u -d -r1.2 -r1.3 --- Config.help 14 Mar 2002 22:32:22 -0000 1.2 +++ Config.help 22 Mar 2002 20:13:57 -0000 1.3 @@ -340,6 +340,19 @@ answer will get "defaulted" for you if you enable any of the Linux CD-ROM drivers). +CONFIG_INPUT_ADBHID + Say Y here if you want to have ADB (Apple Desktop Bus) HID devices + such as keyboards, mice, joysticks, or graphic tablets handled by + the input layer. If you say Y here, make sure to say Y to the + corresponding drivers "Keyboard support" (CONFIG_INPUT_KEYBDEV), + "Mouse Support" (CONFIG_INPUT_MOUSEDEV) and "Event interface + support" (CONFIG_INPUT_EVDEV) as well. + + If you say N here, you still have the option of using the old ADB + keyboard and mouse drivers. + + If unsure, say Y. + CONFIG_PREP_RESIDUAL Some PReP systems have residual data passed to the kernel by the firmware. This allows detection of memory size, devices present and @@ -404,34 +417,6 @@ here. If you also have regular serial ports and enable the driver for them, you can't currently use the serial console feature. -CONFIG_SOUND - If you have a sound card in your computer, i.e. if it can say more - than an occasional beep, say Y. Be sure to have all the information - about your sound card and its configuration down (I/O port, - interrupt and DMA channel), because you will be asked for it. - - You want to read the Sound-HOWTO, available from - <http://www.linuxdoc.org/docs.html#howto>. General information about - the modular sound system is contained in the files - <file:Documentation/sound/Introduction>. The file - <file:Documentation/sound/README.OSS> contains some slightly - outdated but still useful information as well. - - If you have a PnP sound card and you want to configure it at boot - time using the ISA PnP tools (read - <http://www.roestock.demon.co.uk/isapnptools/>), then you need to - compile the sound card support as a module ( = code which can be - inserted in and removed from the running kernel whenever you want) - and load that module after the PnP configuration is finished. To do - this, say M here and read <file:Documentation/modules.txt> as well - as <file:Documentation/sound/README.modules>; the module will be - called soundcore.o. - - I'm told that even without a sound card, you can make your computer - say more than an occasional beep, by programming the PC speaker. - Kernel patches and supporting utilities to do that are in the pcsp - package, available at <ftp://ftp.infradead.org/pub/pcsp/>. - CONFIG_MAGIC_SYSRQ If you say Y here, you will have some control over the system even if the system crashes for example during kernel debugging (e.g., you @@ -865,6 +850,26 @@ Date of Release: early 2001 (?) End of life: - URL: <http://www.microsys.de/html/cu824.html> + +CONFIG_MAC_ADBKEYCODES + This provides support for sending raw ADB keycodes to console + devices. This is the default up to 2.4.0, but in future this may be + phased out in favor of generic Linux keycodes. If you say Y here, + you can dynamically switch via the + /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes + sysctl and with the "keyboard_sends_linux_keycodes=" kernel + argument. + + If unsure, say Y here. + +CONFIG_MAC_EMUMOUSEBTN + This provides generic support for emulating the 2nd and 3rd mouse + button with keypresses. If you say Y here, the emulation is still + disabled by default. The emulation is controlled by these sysctl + entries: + /proc/sys/dev/mac_hid/mouse_button_emulation + /proc/sys/dev/mac_hid/mouse_button2_keycode + /proc/sys/dev/mac_hid/mouse_button3_keycode CONFIG_PPC_RTC If you say Y here and create a character special file /dev/rtc with Index: config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ppc/config.in,v retrieving revision 1.27 retrieving revision 1.28 diff -u -d -r1.27 -r1.28 --- config.in 18 Mar 2002 19:29:09 -0000 1.27 +++ config.in 22 Mar 2002 20:13:57 -0000 1.28 @@ -422,7 +422,6 @@ if [ "$CONFIG_IDE" != "n" ]; then source drivers/ide/Config.in else - define_bool CONFIG_BLK_DEV_IDE_MODES n define_bool CONFIG_BLK_DEV_HD n fi endmenu |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/mips64 In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/mips64 Modified Files: config.in Log Message: Synced to 2.5.7 Index: config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/mips64/config.in,v retrieving revision 1.19 retrieving revision 1.20 diff -u -d -r1.19 -r1.20 --- config.in 14 Mar 2002 22:32:22 -0000 1.19 +++ config.in 22 Mar 2002 20:13:57 -0000 1.20 @@ -147,7 +147,6 @@ if [ "$CONFIG_IDE" != "n" ]; then source drivers/ide/Config.in else - define_bool CONFIG_BLK_DEV_IDE_MODES n define_bool CONFIG_BLK_DEV_HD n fi endmenu |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/sparc
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/sparc
Modified Files:
config.in
Log Message:
Synced to 2.5.7
Index: config.in
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/sparc/config.in,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -d -r1.24 -r1.25
--- config.in 13 Mar 2002 23:48:37 -0000 1.24
+++ config.in 22 Mar 2002 20:13:58 -0000 1.25
@@ -101,14 +101,11 @@
if [ "$CONFIG_IDE" != "n" ]; then
source drivers/ide/Config.in
else
- define_bool CONFIG_BLK_DEV_IDE_MODES n
define_bool CONFIG_BLK_DEV_HD n
fi
endmenu
else
-
define_bool CONFIG_IDE n
- define_bool CONFIG_BLK_DEV_IDE_MODES n
define_bool CONFIG_BLK_DEV_HD n
fi
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:07
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/ppc64/kernel In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/ppc64/kernel Modified Files: ioctl32.c Log Message: Synced to 2.5.7 Index: ioctl32.c =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ppc64/kernel/ioctl32.c,v retrieving revision 1.1 retrieving revision 1.2 diff -u -d -r1.1 -r1.2 --- ioctl32.c 15 Mar 2002 18:28:12 -0000 1.1 +++ ioctl32.c 22 Mar 2002 20:13:58 -0000 1.2 @@ -3721,7 +3721,6 @@ COMPATIBLE_IOCTL(HDIO_SET_MULTCOUNT), COMPATIBLE_IOCTL(HDIO_DRIVE_CMD), COMPATIBLE_IOCTL(HDIO_SET_PIO_MODE), -COMPATIBLE_IOCTL(HDIO_SCAN_HWIF), COMPATIBLE_IOCTL(HDIO_SET_NICE), /* 0x02 -- Floppy ioctls */ COMPATIBLE_IOCTL(FDMSGON), |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:04
|
Update of /cvsroot/linuxconsole/ruby/linux/drivers/char
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/drivers/char
Modified Files:
sysrq.c
Log Message:
Synced to 2.5.7
Index: sysrq.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/drivers/char/sysrq.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -d -r1.19 -r1.20
--- sysrq.c 18 Mar 2002 19:29:10 -0000 1.19
+++ sysrq.c 22 Mar 2002 20:13:58 -0000 1.20
@@ -294,25 +294,21 @@
/* signal sysrq helper function
* Sends a signal to all user processes */
-static void send_sig_all(int sig, int even_init)
+static void send_sig_all(int sig)
{
struct task_struct *p;
for_each_task(p) {
- if (p->mm) { /* Not swapper nor kernel thread */
- if (p->pid == 1 && even_init)
- /* Ugly hack to kill init */
- p->pid = 0x8000;
- if (p->pid != 1)
- force_sig(sig, p);
- }
+ if (p->mm && p->pid != 1)
+ /* Not swapper, init nor kernel thread */
+ force_sig(sig, p);
}
}
static void sysrq_handle_term(int key, struct pt_regs *pt_regs,
struct tty_struct *tty)
{
- send_sig_all(SIGTERM, 0);
+ send_sig_all(SIGTERM);
console_loglevel = 8;
}
static struct sysrq_key_op sysrq_term_op = {
@@ -324,7 +320,7 @@
static void sysrq_handle_kill(int key, struct pt_regs *pt_regs,
struct tty_struct *tty)
{
- send_sig_all(SIGKILL, 0);
+ send_sig_all(SIGKILL);
console_loglevel = 8;
}
static struct sysrq_key_op sysrq_kill_op = {
@@ -333,18 +329,6 @@
action_msg: "Kill All Tasks",
};
-static void sysrq_handle_killall(int key, struct pt_regs *pt_regs,
- struct tty_struct *tty)
-{
- send_sig_all(SIGKILL, 1);
- console_loglevel = 8;
-}
-static struct sysrq_key_op sysrq_killall_op = {
- handler: sysrq_handle_killall,
- help_msg: "killalL",
- action_msg: "Kill All Tasks (even init)",
-};
-
/* END SIGNAL SYSRQ HANDLERS BLOCK */
@@ -379,7 +363,7 @@
#else
/* k */ NULL,
#endif
-/* l */ &sysrq_killall_op,
+/* l */ NULL,
/* m */ &sysrq_showmem_op,
/* n */ NULL,
/* o */ NULL, /* This will often be registered
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:04
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/mips
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/mips
Modified Files:
config.in
Log Message:
Synced to 2.5.7
Index: config.in
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/mips/config.in,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -d -r1.18 -r1.19
--- config.in 14 Mar 2002 22:32:22 -0000 1.18
+++ config.in 22 Mar 2002 20:13:57 -0000 1.19
@@ -337,7 +337,6 @@
if [ "$CONFIG_IDE" != "n" ]; then
source drivers/ide/Config.in
else
- define_bool CONFIG_BLK_DEV_IDE_MODES n
define_bool CONFIG_BLK_DEV_HD n
fi
endmenu
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:04
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/ia64/dig
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/ia64/dig
Modified Files:
setup.c
Log Message:
Synced to 2.5.7
Index: setup.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ia64/dig/setup.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- setup.c 15 Mar 2002 18:59:28 -0000 1.1
+++ setup.c 22 Mar 2002 20:13:57 -0000 1.2
@@ -33,6 +33,7 @@
* is sufficient (the IDE driver will autodetect the drive geometry).
*/
char drive_info[4*16];
+extern int pcat_compat;
void __init
dig_setup (char **cmdline_p)
@@ -79,13 +80,19 @@
screen_info.orig_video_ega_bx = 3; /* XXX fake */
}
-void
+void __init
dig_irq_init (void)
{
- /*
- * Disable the compatibility mode interrupts (8259 style), needs IN/OUT support
- * enabled.
- */
- outb(0xff, 0xA1);
- outb(0xff, 0x21);
+ if (pcat_compat) {
+ /*
+ * Disable the compatibility mode interrupts (8259 style), needs IN/OUT support
+ * enabled.
+ */
+ printk("%s: Disabling PC-AT compatible 8259 interrupts\n", __FUNCTION__);
+ outb(0xff, 0xA1);
+ outb(0xff, 0x21);
+ } else {
+ printk("%s: System doesn't have PC-AT compatible dual-8259 setup. "
+ "Nothing to be done\n", __FUNCTION__);
+ }
}
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:04
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/m68k In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/m68k Modified Files: config.in Log Message: Synced to 2.5.7 Index: config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/m68k/config.in,v retrieving revision 1.15 retrieving revision 1.16 diff -u -d -r1.15 -r1.16 --- config.in 14 Mar 2002 22:32:22 -0000 1.15 +++ config.in 22 Mar 2002 20:13:57 -0000 1.16 @@ -157,7 +157,6 @@ if [ "$CONFIG_IDE" != "n" ]; then source drivers/ide/Config.in else - define_bool CONFIG_BLK_DEV_IDE_MODES n define_bool CONFIG_BLK_DEV_HD n fi endmenu |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:04
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/i386/kernel
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/i386/kernel
Modified Files:
apm.c dmi_scan.c setup.c
Log Message:
Synced to 2.5.7
Index: dmi_scan.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/i386/kernel/dmi_scan.c,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- dmi_scan.c 18 Mar 2002 19:29:09 -0000 1.4
+++ dmi_scan.c 22 Mar 2002 20:13:57 -0000 1.5
@@ -484,6 +484,11 @@
MATCH(DMI_BIOS_VERSION, "A04"),
MATCH(DMI_BIOS_DATE, "08/24/2000"), NO_MATCH
} },
+ { broken_apm_power, "Dell Inspiron 2500", { /* Handle problems with APM on Inspiron 2500 */
+ MATCH(DMI_BIOS_VENDOR, "Phoenix Technologies LTD"),
+ MATCH(DMI_BIOS_VERSION, "A12"),
+ MATCH(DMI_BIOS_DATE, "02/04/2002"), NO_MATCH
+ } },
{ set_realmode_power_off, "Award Software v4.60 PGMA", { /* broken PM poweroff bios */
MATCH(DMI_BIOS_VENDOR, "Award Software International, Inc."),
MATCH(DMI_BIOS_VERSION, "4.60 PGMA"),
Index: setup.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/i386/kernel/setup.c,v
retrieving revision 1.37
retrieving revision 1.38
diff -u -d -r1.37 -r1.38
--- setup.c 18 Mar 2002 19:29:09 -0000 1.37
+++ setup.c 22 Mar 2002 20:13:57 -0000 1.38
@@ -92,6 +92,7 @@
#include <linux/delay.h>
#include <linux/config.h>
#include <linux/init.h>
+#include <linux/acpi.h>
#include <linux/apm_bios.h>
#ifdef CONFIG_BLK_DEV_RAM
#include <linux/blk.h>
@@ -165,8 +166,6 @@
static int disable_x86_serial_nr __initdata = 1;
static int disable_x86_fxsr __initdata = 0;
-int enable_acpi_smp_table;
-
/*
* This is set up by the setup-routine at boot-time
*/
@@ -639,9 +638,6 @@
add_memory_region(start_at, mem_size, E820_RAM);
}
}
- /* acpismp=force forces parsing and use of the ACPI SMP table */
- if (c == ' ' && !memcmp(from, "acpismp=force", 13))
- enable_acpi_smp_table = 1;
/*
* highmem=size forces highmem to be exactly 'size' bytes.
* This works even on boxes that have no highmem otherwise.
@@ -865,7 +861,12 @@
*/
reserve_bootmem(PAGE_SIZE, PAGE_SIZE);
#endif
-
+#ifdef CONFIG_ACPI_SLEEP
+ /*
+ * Reserve low memory region for sleep support.
+ */
+ acpi_reserve_bootmem();
+#endif
#ifdef CONFIG_X86_LOCAL_APIC
/*
* Find and reserve possible boot-time SMP configuration:
@@ -899,6 +900,15 @@
smp_alloc_memory(); /* AP processor realmode stacks in low memory*/
#endif
paging_init();
+#ifdef CONFIG_ACPI_BOOT
+ /*
+ * Initialize the ACPI boot-time table parser (gets the RSDP and SDT).
+ * Must do this after paging_init (due to reliance on fixmap, and thus
+ * the bootmem allocator) but before get_smp_config (to allow parsing
+ * of MADT).
+ */
+ acpi_table_init(*cmdline_p);
+#endif
#ifdef CONFIG_X86_LOCAL_APIC
/*
* get boot-time SMP configuration:
@@ -1949,13 +1959,10 @@
static void __init init_intel(struct cpuinfo_x86 *c)
{
-#ifndef CONFIG_M686
- static int f00f_workaround_enabled = 0;
-#endif
char *p = NULL;
unsigned int l1i = 0, l1d = 0, l2 = 0, l3 = 0; /* Cache sizes */
-#ifndef CONFIG_M686
+#ifdef CONFIG_X86_F00F_BUG
/*
* All current models of Pentium and Pentium with MMX technology CPUs
* have the F0 0F bug, which lets nonpriviledged users lock up the system.
@@ -1963,6 +1970,8 @@
*/
c->f00f_bug = 0;
if ( c->x86 == 5 ) {
+ static int f00f_workaround_enabled = 0;
+
c->f00f_bug = 1;
if ( !f00f_workaround_enabled ) {
trap_init_f00f_bug();
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/ia64
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/ia64
Modified Files:
config.in
Log Message:
Synced to 2.5.7
Index: config.in
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/ia64/config.in,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- config.in 14 Mar 2002 22:32:22 -0000 1.20
+++ config.in 22 Mar 2002 20:13:57 -0000 1.21
@@ -1,9 +1,9 @@
-mainmenu_name "Kernel configuration of Linux for IA-64 machines"
+mainmenu_name "IA-64 Linux Kernel Configuration"
source init/Config.in
mainmenu_option next_comment
-comment 'General setup'
+comment 'Processor type and features'
define_bool CONFIG_IA64 y
@@ -14,13 +14,6 @@
define_bool CONFIG_RWSEM_GENERIC_SPINLOCK y
define_bool CONFIG_RWSEM_XCHGADD_ALGORITHM n
-if [ "$CONFIG_IA64_HP_SIM" = "n" ]; then
- define_bool CONFIG_ACPI y
- define_bool CONFIG_ACPI_EFI y
- define_bool CONFIG_ACPI_INTERPRETER y
- define_bool CONFIG_ACPI_KERNEL_CONFIG y
-fi
-
choice 'IA-64 processor type' \
"Itanium CONFIG_ITANIUM \
McKinley CONFIG_MCKINLEY" Itanium
@@ -38,6 +31,13 @@
16KB CONFIG_IA64_PAGE_SIZE_16KB \
64KB CONFIG_IA64_PAGE_SIZE_64KB" 16KB
+if [ "$CONFIG_IA64_HP_SIM" = "n" ]; then
+ define_bool CONFIG_ACPI y
+ define_bool CONFIG_ACPI_EFI y
+ define_bool CONFIG_ACPI_INTERPRETER y
+ define_bool CONFIG_ACPI_KERNEL_CONFIG y
+fi
+
if [ "$CONFIG_ITANIUM" = "y" ]; then
define_bool CONFIG_IA64_BRL_EMU y
bool ' Enable Itanium B-step specific code' CONFIG_ITANIUM_BSTEP_SPECIFIC
@@ -119,6 +119,7 @@
source drivers/mtd/Config.in
source drivers/pnp/Config.in
source drivers/block/Config.in
+source drivers/ieee1394/Config.in
source drivers/message/i2o/Config.in
source drivers/md/Config.in
@@ -130,11 +131,21 @@
if [ "$CONFIG_IDE" != "n" ]; then
source drivers/ide/Config.in
else
- define_bool CONFIG_BLK_DEV_IDE_MODES n
define_bool CONFIG_BLK_DEV_HD n
fi
endmenu
+else # ! HP_SIM
+mainmenu_option next_comment
+comment 'Block devices'
+tristate 'Loopback device support' CONFIG_BLK_DEV_LOOP
+dep_tristate 'Network block device support' CONFIG_BLK_DEV_NBD $CONFIG_NET
+
+tristate 'RAM disk support' CONFIG_BLK_DEV_RAM
+if [ "$CONFIG_BLK_DEV_RAM" = "y" -o "$CONFIG_BLK_DEV_RAM" = "m" ]; then
+ int ' Default RAM disk size' CONFIG_BLK_DEV_RAM_SIZE 4096
+fi
+endmenu
fi # !HP_SIM
mainmenu_option next_comment
@@ -216,15 +227,7 @@
fi # !HP_SIM
if [ "$CONFIG_IA64_HP_SIM" != "n" -o "$CONFIG_IA64_GENERIC" != "n" ]; then
- mainmenu_option next_comment
- comment 'Simulated drivers'
-
- tristate 'Simulated Ethernet ' CONFIG_SIMETH
- bool 'Simulated serial driver support' CONFIG_SIM_SERIAL
- if [ "$CONFIG_SCSI" != "n" ]; then
- bool 'Simulated SCSI disk' CONFIG_SCSI_SIM
- fi
- endmenu
+ source arch/ia64/hp/Config.in
fi
@@ -241,9 +244,7 @@
bool ' Disable VHPT' CONFIG_DISABLE_VHPT
bool ' Magic SysRq key' CONFIG_MAGIC_SYSRQ
-# early printk is currently broken for SMP: the secondary processors get stuck...
-# bool ' Early printk support (requires VGA!)' CONFIG_IA64_EARLY_PRINTK
-
+ bool ' Early printk support (requires VGA!)' CONFIG_IA64_EARLY_PRINTK
bool ' Debug memory allocations' CONFIG_DEBUG_SLAB
bool ' Spinlock debugging' CONFIG_DEBUG_SPINLOCK
bool ' Turn on compare-and-exchange bug checking (slow!)' CONFIG_IA64_DEBUG_CMPXCHG
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/i386
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/i386
Modified Files:
config.in
Log Message:
Synced to 2.5.7
Index: config.in
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/i386/config.in,v
retrieving revision 1.35
retrieving revision 1.36
diff -u -d -r1.35 -r1.36
--- config.in 14 Mar 2002 22:32:21 -0000 1.35
+++ config.in 22 Mar 2002 20:13:57 -0000 1.36
@@ -41,6 +41,7 @@
define_bool CONFIG_RWSEM_GENERIC_SPINLOCK y
define_bool CONFIG_RWSEM_XCHGADD_ALGORITHM n
define_bool CONFIG_X86_PPRO_FENCE y
+ define_bool CONFIG_X86_F00F_BUG y
else
define_bool CONFIG_X86_WP_WORKS_OK y
define_bool CONFIG_X86_INVLPG y
@@ -56,12 +57,14 @@
define_bool CONFIG_X86_USE_STRING_486 y
define_bool CONFIG_X86_ALIGNMENT_16 y
define_bool CONFIG_X86_PPRO_FENCE y
+ define_bool CONFIG_X86_F00F_BUG y
fi
if [ "$CONFIG_M586" = "y" ]; then
define_int CONFIG_X86_L1_CACHE_SHIFT 5
define_bool CONFIG_X86_USE_STRING_486 y
define_bool CONFIG_X86_ALIGNMENT_16 y
define_bool CONFIG_X86_PPRO_FENCE y
+ define_bool CONFIG_X86_F00F_BUG y
fi
if [ "$CONFIG_M586TSC" = "y" ]; then
define_int CONFIG_X86_L1_CACHE_SHIFT 5
@@ -69,6 +72,7 @@
define_bool CONFIG_X86_ALIGNMENT_16 y
define_bool CONFIG_X86_TSC y
define_bool CONFIG_X86_PPRO_FENCE y
+ define_bool CONFIG_X86_F00F_BUG y
fi
if [ "$CONFIG_M586MMX" = "y" ]; then
define_int CONFIG_X86_L1_CACHE_SHIFT 5
@@ -77,6 +81,7 @@
define_bool CONFIG_X86_TSC y
define_bool CONFIG_X86_GOOD_APIC y
define_bool CONFIG_X86_PPRO_FENCE y
+ define_bool CONFIG_X86_F00F_BUG y
fi
if [ "$CONFIG_M686" = "y" ]; then
define_int CONFIG_X86_L1_CACHE_SHIFT 5
@@ -203,6 +208,8 @@
mainmenu_option next_comment
comment 'General options'
+source drivers/acpi/Config.in
+
# Visual Workstation support is utterly broken.
# If you want to see it working mail an VW540 to hc...@in... 8)
#bool 'SGI Visual Workstation support' CONFIG_VISWS
@@ -261,14 +268,6 @@
bool 'Power Management support' CONFIG_PM
-if [ "$CONFIG_EXPERIMENTAL" = "y" ]; then
- dep_bool ' ACPI support' CONFIG_ACPI $CONFIG_PM
-
- if [ "$CONFIG_ACPI" != "n" ]; then
- source drivers/acpi/Config.in
- fi
-fi
-
dep_tristate ' Advanced Power Management BIOS support' CONFIG_APM $CONFIG_PM
if [ "$CONFIG_APM" != "n" ]; then
bool ' Ignore USER SUSPEND' CONFIG_APM_IGNORE_USER_SUSPEND
@@ -308,7 +307,6 @@
if [ "$CONFIG_IDE" != "n" ]; then
source drivers/ide/Config.in
else
- define_bool CONFIG_BLK_DEV_IDE_MODES n
define_bool CONFIG_BLK_DEV_HD n
fi
endmenu
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/i386/mm In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/i386/mm Modified Files: fault.c Log Message: Synced to 2.5.7 Index: fault.c =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/i386/mm/fault.c,v retrieving revision 1.9 retrieving revision 1.10 diff -u -d -r1.9 -r1.10 --- fault.c 14 Mar 2002 22:32:21 -0000 1.9 +++ fault.c 22 Mar 2002 20:13:57 -0000 1.10 @@ -280,6 +280,7 @@ return; } +#ifdef CONFIG_X86_F00F_BUG /* * Pentium F0 0F C7 C8 bug workaround. */ @@ -293,6 +294,7 @@ return; } } +#endif no_context: /* Are we prepared to handle this kernel fault? */ |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/arm In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/arm Modified Files: config.in Log Message: Synced to 2.5.7 Index: config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/arm/config.in,v retrieving revision 1.21 retrieving revision 1.22 diff -u -d -r1.21 -r1.22 --- config.in 20 Jan 2002 03:54:44 -0000 1.21 +++ config.in 22 Mar 2002 20:13:57 -0000 1.22 @@ -577,7 +577,6 @@ if [ "$CONFIG_IDE" != "n" ]; then source drivers/ide/Config.in else - define_bool CONFIG_BLK_DEV_IDE_MODES n define_bool CONFIG_BLK_DEV_HD n fi endmenu |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/cris In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/cris Modified Files: config.in Log Message: Synced to 2.5.7 Index: config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/cris/config.in,v retrieving revision 1.9 retrieving revision 1.10 diff -u -d -r1.9 -r1.10 --- config.in 14 Mar 2002 22:32:21 -0000 1.9 +++ config.in 22 Mar 2002 20:13:57 -0000 1.10 @@ -149,7 +149,6 @@ if [ "$CONFIG_IDE" != "n" ]; then source drivers/ide/Config.in else - define_bool CONFIG_BLK_DEV_IDE_MODES n define_bool CONFIG_BLK_DEV_HD n fi endmenu |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/alpha In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/alpha Modified Files: config.in Log Message: Synced to 2.5.7 Index: config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/arch/alpha/config.in,v retrieving revision 1.27 retrieving revision 1.28 diff -u -d -r1.27 -r1.28 --- config.in 18 Mar 2002 19:29:08 -0000 1.27 +++ config.in 22 Mar 2002 20:13:56 -0000 1.28 @@ -290,7 +290,6 @@ if [ "$CONFIG_IDE" != "n" ]; then source drivers/ide/Config.in else - define_bool CONFIG_BLK_DEV_IDE_MODES n define_bool CONFIG_BLK_DEV_HD n fi endmenu |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:03
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/arm/kernel
In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux/arch/arm/kernel
Modified Files:
setup.c
Log Message:
Synced to 2.5.7
Index: setup.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/arm/kernel/setup.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -d -r1.8 -r1.9
--- setup.c 18 Mar 2002 19:29:08 -0000 1.8
+++ setup.c 22 Mar 2002 20:13:57 -0000 1.9
@@ -75,6 +75,9 @@
#ifdef MULTI_TLB
struct cpu_tlb_fns cpu_tlb;
#endif
+#ifdef MULTI_USER
+struct cpu_user_fns cpu_user;
+#endif
char elf_platform[ELF_PLATFORM_SIZE];
char saved_command_line[COMMAND_LINE_SIZE];
@@ -245,6 +248,9 @@
#endif
#ifdef MULTI_TLB
cpu_tlb = *list->tlb;
+#endif
+#ifdef MULTI_USER
+ cpu_user = *list->user;
#endif
printk("Processor: %s %s revision %d\n",
|
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:01
|
Update of /cvsroot/linuxconsole/ruby In directory usw-pr-cvs1:/tmp/cvs-serv1749 Added Files: AGAINST-2.5.7 Removed Files: AGAINST-2.5.6 Log Message: Synced to 2.5.7 --- NEW FILE: AGAINST-2.5.7 --- --- AGAINST-2.5.6 DELETED --- |
|
From: James S. <jsi...@us...> - 2002-03-22 20:14:01
|
Update of /cvsroot/linuxconsole/ruby/linux In directory usw-pr-cvs1:/tmp/cvs-serv1749/linux Modified Files: Makefile Log Message: Synced to 2.5.7 Index: Makefile =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/Makefile,v retrieving revision 1.48 retrieving revision 1.49 diff -u -d -r1.48 -r1.49 --- Makefile 18 Mar 2002 19:29:08 -0000 1.48 +++ Makefile 22 Mar 2002 20:13:56 -0000 1.49 @@ -1,6 +1,6 @@ VERSION = 2 PATCHLEVEL = 5 -SUBLEVEL = 6 +SUBLEVEL = 7 EXTRAVERSION = -ruby KERNELRELEASE=$(VERSION).$(PATCHLEVEL).$(SUBLEVEL)$(EXTRAVERSION) @@ -169,7 +169,6 @@ DRIVERS-$(CONFIG_DIO) += drivers/dio/dio.a DRIVERS-$(CONFIG_SBUS) += drivers/sbus/sbus_all.o DRIVERS-$(CONFIG_ZORRO) += drivers/zorro/driver.o -DRIVERS-$(CONFIG_FC4) += drivers/fc4/fc4.a DRIVERS-$(CONFIG_ALL_PPC) += drivers/macintosh/macintosh.o DRIVERS-$(CONFIG_MAC) += drivers/macintosh/macintosh.o DRIVERS-$(CONFIG_PNP) += drivers/pnp/pnp.o @@ -247,14 +246,14 @@ include arch/$(ARCH)/Makefile -export CPPFLAGS CFLAGS AFLAGS +export CPPFLAGS CFLAGS CFLAGS_KERNEL AFLAGS AFLAGS_KERNEL export NETWORKS DRIVERS LIBS HEAD LDFLAGS LINKFLAGS MAKEBOOT ASFLAGS .S.s: - $(CPP) $(AFLAGS) -traditional -o $*.s $< + $(CPP) $(AFLAGS) $(AFLAGS_KERNEL) -traditional -o $*.s $< .S.o: - $(CC) $(AFLAGS) -traditional -c -o $*.o $< + $(CC) $(AFLAGS) $(AFLAGS_KERNEL) -traditional -c -o $*.o $< Version: dummy @rm -f include/linux/compile.h |
|
From: johann d. <jd...@us...> - 2002-03-20 21:43:28
|
Update of /cvsroot/linuxconsole/ruby/linux/drivers/input
In directory usw-pr-cvs1:/tmp/cvs-serv9123
Modified Files:
evdev.c joydev.c
Log Message:
Check that the device exists before accessing it (in writes, reads and ioctls).
Index: evdev.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/drivers/input/evdev.c,v
retrieving revision 1.46
retrieving revision 1.47
diff -u -d -r1.46 -r1.47
--- evdev.c 3 Feb 2002 19:34:38 -0000 1.46
+++ evdev.c 20 Mar 2002 21:43:25 -0000 1.47
@@ -90,7 +90,9 @@
static int evdev_flush(struct file * file)
{
- return input_flush_device(&((struct evdev_list*)file->private_data)->evdev->handle, file);
+ struct evdev_list *list = (struct evdev_list*)file->private_data;
+ if (!list->evdev->exist) return -ENODEV;
+ return input_flush_device(&list->evdev->handle, file);
}
static int evdev_release(struct inode * inode, struct file * file)
@@ -157,6 +159,8 @@
struct input_event event;
int retval = 0;
+ if (!list->evdev->exist) return -ENODEV;
+
while (retval < count) {
if (copy_from_user(&event, buffer + retval, sizeof(struct input_event)))
@@ -230,6 +234,8 @@
struct evdev *evdev = list->evdev;
struct input_dev *dev = evdev->handle.dev;
int retval, t, u;
+
+ if (!evdev->exist) return -ENODEV;
switch (cmd) {
Index: joydev.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/drivers/input/joydev.c,v
retrieving revision 1.41
retrieving revision 1.42
diff -u -d -r1.41 -r1.42
--- joydev.c 18 Mar 2002 19:29:10 -0000 1.41
+++ joydev.c 20 Mar 2002 21:43:25 -0000 1.42
@@ -254,6 +254,10 @@
while (list->head == list->tail) {
+ if (!joydev->exist) {
+ retval = -ENODEV;
+ break;
+ }
if (file->f_flags & O_NONBLOCK) {
retval = -EAGAIN;
break;
@@ -324,6 +328,8 @@
struct joydev *joydev = list->joydev;
struct input_dev *dev = joydev->handle.dev;
int i;
+
+ if (!joydev->exist) return -ENODEV;
switch (cmd) {
|
|
From: James S. <jsi...@us...> - 2002-03-19 19:21:22
|
Update of /cvsroot/linuxconsole/ruby/linux/drivers/input/mouse In directory usw-pr-cvs1:/tmp/cvs-serv19608 Modified Files: Config.in Makefile Log Message: Moved gunze.c to touchscreen directory. Index: Config.in =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/drivers/input/mouse/Config.in,v retrieving revision 1.1 retrieving revision 1.2 diff -u -d -r1.1 -r1.2 --- Config.in 23 Jan 2002 05:33:44 -0000 1.1 +++ Config.in 19 Mar 2002 19:21:19 -0000 1.2 @@ -6,7 +6,6 @@ dep_tristate ' PS/2 mouse' CONFIG_MOUSE_PS2 $CONFIG_INPUT $CONFIG_INPUT_MOUSE $CONFIG_SERIO dep_tristate ' Serial mouse' CONFIG_MOUSE_SERIAL $CONFIG_INPUT $CONFIG_INPUT_MOUSE $CONFIG_SERIO -dep_tristate ' Gunze AHL-51S touchscreen' CONFIG_MOUSE_GUNZE $CONFIG_INPUT $CONFIG_INPUT_MOUSE $CONFIG_SERIO dep_tristate ' InPort/MS/ATIXL busmouse' CONFIG_MOUSE_INPORT $CONFIG_INPUT $CONFIG_INPUT_MOUSE $CONFIG_ISA if [ "$CONFIG_MOUSE_INPORT" != "n" ]; then Index: Makefile =================================================================== RCS file: /cvsroot/linuxconsole/ruby/linux/drivers/input/mouse/Makefile,v retrieving revision 1.1 retrieving revision 1.2 diff -u -d -r1.1 -r1.2 --- Makefile 23 Jan 2002 05:28:12 -0000 1.1 +++ Makefile 19 Mar 2002 19:21:19 -0000 1.2 @@ -10,7 +10,6 @@ obj-$(CONFIG_MOUSE_AMIGA) += amimouse.o obj-$(CONFIG_MOUSE_ACORN) += rpcmouse.o -obj-$(CONFIG_MOUSE_GUNZE) += gunze.o obj-$(CONFIG_MOUSE_INPORT) += inport.o obj-$(CONFIG_MOUSE_LOGIBM) += logibm.o obj-$(CONFIG_MOUSE_MAPLE) += maplemouse.o |
|
From: James S. <jsi...@us...> - 2002-03-19 19:08:08
|
Update of /cvsroot/linuxconsole/ruby/linux/arch/alpha/kernel
In directory usw-pr-cvs1:/tmp/cvs-serv13775
Modified Files:
setup.c
Log Message:
wait_key doesn't exist anymore.
Index: setup.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/alpha/kernel/setup.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- setup.c 14 Mar 2002 20:02:06 -0000 1.7
+++ setup.c 19 Mar 2002 19:08:03 -0000 1.8
@@ -438,12 +438,6 @@
return mk_kdev(TTY_MAJOR, 64 + c->index);
}
-static int srm_console_wait_key(struct console *co)
-{
- /* Huh? */
- return 1;
-}
-
static int __init srm_console_setup(struct console *co, char *options)
{
return 1;
@@ -453,7 +447,6 @@
name: "srm0",
write: srm_console_write,
device: srm_console_device,
- wait_key: srm_console_wait_key,
setup: srm_console_setup,
flags: CON_PRINTBUFFER | CON_ENABLED, /* fake it out */
index: -1,
|
Index: apm.c
===================================================================
RCS file: /cvsroot/linuxconsole/ruby/linux/arch/i386/kernel/apm.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- apm.c 18 Mar 2002 19:29:09 -0000 1.2
+++ apm.c 22 Mar 2002 20:13:57 -0000 1.3
@@ -275,10 +275,11 @@
*/
/*
- * Define to always call the APM BIOS busy routine even if the clock was
- * not slowed by the idle routine.
+ * Define as 1 to make the driver always call the APM BIOS busy
+ * routine even if the clock was not reported as slowed by the
+ * idle routine. Otherwise, define as 0.
*/
-#define ALWAYS_CALL_BUSY
+#define ALWAYS_CALL_BUSY 1
/*
* Define to make the APM BIOS calls zero all data segment registers (so
@@ -380,7 +381,7 @@
static int set_pm_idle;
static int suspends_pending;
static int standbys_pending;
-static int waiting_for_resume;
+static int ignore_sys_suspend;
static int ignore_normal_resume;
static int bounce_interval = DEFAULT_BOUNCE_INTERVAL;
@@ -471,6 +472,28 @@
};
#define ERROR_COUNT (sizeof(error_table)/sizeof(lookup_t))
+/**
+ * apm_error - display an APM error
+ * @str: information string
+ * @err: APM BIOS return code
+ *
+ * Write a meaningful log entry to the kernel log in the event of
+ * an APM error.
+ */
+
+static void apm_error(char *str, int err)
+{
+ int i;
+
+ for (i = 0; i < ERROR_COUNT; i++)
+ if (error_table[i].key == err) break;
+ if (i < ERROR_COUNT)
+ printk(KERN_NOTICE "apm: %s: %s\n", str, error_table[i].msg);
+ else
+ printk(KERN_NOTICE "apm: %s: unknown error code %#2.2x\n",
+ str, err);
+}
+
/*
* These are the actual BIOS calls. Depending on APM_ZERO_SEGS and
* apm_info.allow_ints, we are being really paranoid here! Not only
@@ -702,13 +725,13 @@
}
/**
* apm_set_power_state - set system wide power state
* @state: which state to enter
*
* Transition the entire system into a new APM power state.
*/
-static int apm_set_power_state(u_short state)
+static int set_system_power_state(u_short state)
{
return set_power_state(APM_DEVICE_ALL, state);
}
@@ -725,7 +748,6 @@
static int apm_do_idle(void)
{
u32 eax;
- int slowed;
if (apm_bios_call_simple(APM_FUNC_IDLE, 0, 0, &eax)) {
static unsigned long t;
@@ -737,13 +759,8 @@
}
return -1;
}
- slowed = (apm_info.bios.flags & APM_IDLE_SLOWS_CLOCK) != 0;
-#ifdef ALWAYS_CALL_BUSY
- clock_slowed = 1;
-#else
- clock_slowed = slowed;
-#endif
- return slowed;
+ clock_slowed = (apm_info.bios.flags & APM_IDLE_SLOWS_CLOCK) != 0;
+ return clock_slowed;
}
/**
@@ -756,7 +773,7 @@
{
u32 dummy;
- if (clock_slowed) {
+ if (clock_slowed || ALWAYS_CALL_BUSY) {
(void) apm_bios_call_simple(APM_FUNC_BUSY, 0, 0, &dummy);
clock_slowed = 0;
}
@@ -771,7 +788,7 @@
#define IDLE_CALC_LIMIT (HZ * 100)
#define IDLE_LEAKY_MAX 16
-static void (*sys_idle)(void);
+static void (*original_pm_idle)(void);
extern void default_idle(void);
@@ -785,14 +802,13 @@
static void apm_cpu_idle(void)
{
- static int use_apm_idle = 0;
- static unsigned int last_jiffies = 0;
- static unsigned int last_stime = 0;
+ static int use_apm_idle; /* = 0 */
+ static unsigned int last_jiffies; /* = 0 */
+ static unsigned int last_stime; /* = 0 */
- int apm_is_idle = 0;
+ int apm_idle_done = 0;
unsigned int jiffies_since_last_check = jiffies - last_jiffies;
- unsigned int t1;
-
+ unsigned int bucket;
recalc:
if (jiffies_since_last_check > IDLE_CALC_LIMIT) {
@@ -810,7 +826,7 @@
last_stime = current->times.tms_stime;
}
- t1 = IDLE_LEAKY_MAX;
+ bucket = IDLE_LEAKY_MAX;
while (!need_resched()) {
if (use_apm_idle) {
@@ -818,23 +834,24 @@
t = jiffies;
switch (apm_do_idle()) {
- case 0: apm_is_idle = 1;
+ case 0: apm_idle_done = 1;
if (t != jiffies) {
- if (t1) {
- t1 = IDLE_LEAKY_MAX;
+ if (bucket) {
+ bucket = IDLE_LEAKY_MAX;
continue;
}
- } else if (t1) {
- t1--;
+ } else if (bucket) {
+ bucket--;
continue;
}
break;
- case 1: apm_is_idle = 1;
+ case 1: apm_idle_done = 1;
break;
+ default: /* BIOS refused */
}
}
- if (sys_idle)
- sys_idle();
+ if (original_pm_idle)
+ original_pm_idle();
else
default_idle();
jiffies_since_last_check = jiffies - last_jiffies;
@@ -842,7 +859,7 @@
goto recalc;
}
- if (apm_is_idle)
+ if (apm_idle_done)
apm_do_busy();
}
@@ -890,7 +907,7 @@
if (apm_info.realmode_power_off)
machine_real_restart(po_bios_call, sizeof(po_bios_call));
else
- (void) apm_set_power_state(APM_STATE_OFF);
+ (void) set_system_power_state(APM_STATE_OFF);
}
/**
@@ -1035,28 +1052,6 @@
return APM_SUCCESS;
}
-/**
- * apm_error - display an APM error
- * @str: information string
- * @err: APM BIOS return code
- *
- * Write a meaningful log entry to the kernel log in the event of
- * an APM error.
- */
-
-static void apm_error(char *str, int err)
-{
- int i;
-
- for (i = 0; i < ERROR_COUNT; i++)
- if (error_table[i].key == err) break;
- if (i < ERROR_COUNT)
- printk(KERN_NOTICE "apm: %s: %s\n", str, error_table[i].msg);
- else
- printk(KERN_NOTICE "apm: %s: unknown error code %#2.2x\n",
- str, err);
-}
-
#if defined(CONFIG_APM_DISPLAY_BLANK) && defined(CONFIG_VT)
/**
@@ -1198,9 +1193,9 @@
/* Vetoed */
if (vetoable) {
if (apm_info.connection_version > 0x100)
- apm_set_power_state(APM_STATE_REJECT);
+ set_system_power_state(APM_STATE_REJECT);
err = -EBUSY;
- waiting_for_resume = 0;
+ ignore_sys_suspend = 0;
printk(KERN_WARNING "apm: suspend was vetoed.\n");
goto out;
}
@@ -1208,9 +1203,10 @@
}
get_time_diff();
cli();
- err = apm_set_power_state(APM_STATE_SUSPEND);
+ err = set_system_power_state(APM_STATE_SUSPEND);
reinit_timer();
set_time();
+ ignore_normal_resume = 1;
sti();
if (err == APM_NO_ERROR)
err = APM_SUCCESS;
@@ -1219,7 +1215,6 @@
err = (err == APM_SUCCESS) ? 0 : -EIO;
pm_send_all(PM_RESUME, (void *)0);
queue_event(APM_NORMAL_RESUME, NULL);
- ignore_normal_resume = 1;
out:
spin_lock(&user_list_lock);
for (as = user_list; as != NULL; as = as->next) {
@@ -1237,7 +1232,7 @@
/* If needed, notify drivers here */
get_time_diff();
- err = apm_set_power_state(APM_STATE_STANDBY);
+ err = set_system_power_state(APM_STATE_STANDBY);
if ((err != APM_SUCCESS) && (err != APM_NO_ERROR))
apm_error("standby", err);
}
@@ -1291,13 +1286,13 @@
case APM_USER_SUSPEND:
#ifdef CONFIG_APM_IGNORE_USER_SUSPEND
if (apm_info.connection_version > 0x100)
- apm_set_power_state(APM_STATE_REJECT);
+ set_system_power_state(APM_STATE_REJECT);
break;
#endif
case APM_SYS_SUSPEND:
if (ignore_bounce) {
if (apm_info.connection_version > 0x100)
- apm_set_power_state(APM_STATE_REJECT);
+ set_system_power_state(APM_STATE_REJECT);
break;
}
/*
@@ -1308,9 +1303,9 @@
* sending a SUSPEND event until something else
* happens!
*/
- if (waiting_for_resume)
+ if (ignore_sys_suspend)
return;
- waiting_for_resume = 1;
+ ignore_sys_suspend = 1;
queue_event(event, NULL);
if (suspends_pending <= 0)
(void) suspend(1);
@@ -1319,7 +1314,7 @@
case APM_NORMAL_RESUME:
case APM_CRITICAL_RESUME:
case APM_STANDBY_RESUME:
- waiting_for_resume = 0;
+ ignore_sys_suspend = 0;
last_resume = jiffies;
ignore_bounce = 1;
if ((event != APM_NORMAL_RESUME)
@@ -1363,7 +1358,7 @@
pending_count = 4;
if (debug)
printk(KERN_DEBUG "apm: setting state busy\n");
- err = apm_set_power_state(APM_STATE_BUSY);
+ err = set_system_power_state(APM_STATE_BUSY);
if (err)
apm_error("busy", err);
}
@@ -1972,7 +1967,7 @@
if (HZ != 100)
idle_period = (idle_period * HZ) / 100;
if (idle_threshold < 100) {
- sys_idle = pm_idle;
+ original_pm_idle = pm_idle;
pm_idle = apm_cpu_idle;
set_pm_idle = 1;
}
@@ -1985,7 +1980,7 @@
int error;
if (set_pm_idle)
- pm_idle = sys_idle;
+ pm_idle = original_pm_idle;
if (((apm_info.bios.flags & APM_BIOS_DISENGAGED) == 0)
&& (apm_info.connection_version > 0x0100)) {
error = apm_engage_power_management(APM_DEVICE_ALL, 0);
@@ -702,13 +725,13 @@
}
/**
- * apm_set_power_state - set system wide power state
+ * set_system_power_state - set system wide power state
* @state: which state to enter
*